import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_evaluate_form.dart';
import 'package:cramr_ui_lib/theme/custom_theme.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:provider/provider.dart';

/// The Route that allows you to show the evaluation of the indicative of the
/// [Verb] that you are studying.
class VerbIndicativeEvaluateRoute extends StatelessWidget {

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: "Evaluatie",
      theme: CustomTheme.lightTheme,
      home: Scaffold(
        body: VerbIndicativeEvaluateForm(),
        bottomNavigationBar: BottomNavigationBar(
          key: UniqueKey(),
          items: [
            BottomNavigationBarItem(
                label: 'Menu',
                icon: _chooseNewVerbIcon(context)
            ),
            BottomNavigationBarItem(
              label: 'Herhaal',
              icon: _onceMoreIcon(context),
            ),
            BottomNavigationBarItem(
              label: 'Stop',
              icon: _quitIcon(context),
            )
          ],
        ),
      ),
    );
  }

  void _onceMore(BuildContext context, VerbTestModel model) {
    model.reset();
    //back to study
    Navigator.restorablePopAndPushNamed(context, '/verbIndicativeStudyRoute');
  }

  void _chooseNewVerb(BuildContext context, VerbTestModel model) {
    model.reset();
    //back to verb selection
    Navigator.restorablePopAndPushNamed(context, '/verbSelectionRoute');

  }

  void _quit(BuildContext context) {
    VerbTestModel testModel = Provider.of<VerbTestModel>(context, listen: false);
    testModel.dispose();
    SystemNavigator.pop();
  }

  InkWell _onceMoreIcon(BuildContext context) {
    VerbTestModel testModel = context.watch<VerbTestModel>();
    return InkWell(
      key: Key('repeat_key'),
      child: Icon(Icons.refresh),
      onTap: () => _onceMore(context, testModel),
    );
  }

  InkWell _chooseNewVerbIcon(BuildContext context) {
    VerbTestModel testModel = context.watch<VerbTestModel>();
    return InkWell(
      key: Key('menu_key'),
      child: Icon(Icons.home),
      onTap: () => _chooseNewVerb(context, testModel),
    );
  }

  InkWell _quitIcon(BuildContext context) {
    return InkWell(
      key: Key('quit_key'),
      child: Icon(Icons.stop),
      onTap: () => _quit(context),
    );
  }
}